function [Yk1,Xk1] = GDTODESampler(Xk,Uk,diffeqstr,Ts,C)
% GDTODESampler Simulates an ordinary differential equation from t to t+Ts
%       x' = f(x,u); 
%       y  = C*x
% and returns y and x sampled at t+Ts.
%
%   [Yk1,Xk1] = GDTODESampler(Xk,Uk,diffeqstr,Ts,C)
%
% Xk    Initial state at t
% Uk    Control at t
% Yk1   State at t+Ts
% Xk1   Output at t+Ts
% Ts    sampling time
% C     measurement 
%
% diffeqstr is the name of the file containing system differential equations. 
% It should have the form: xdot = fun(t,x,u)

% Enso Ikonen 4/2006 University of Oulu

% Solve diff. eqs from t to t+Ts
fstr = sprintf('ode23(@%s,[0 Ts],Xk,[],Uk)',diffeqstr);
[t,X] = eval(fstr);
% Read states at t0+Ts
l = length(t);
Xk1 = X(l,:)';

% Measure outputs
Yk1 = C*Xk1;
