function gdt_plot(GDT)
% GDT_PLOT  Plot outcomes of a GDT simulation
%   gdt_plot(GDT)
% where GDT is a GDT-structure.

% Enso Ikonen 4/2006 University of Oulu

% find optimal trajectory
N=length(GDT);
I = [1:N]';
J_T = [GDT(I).J_T];
i_opt = find( J_T == min(J_T) ); i_opt = i_opt(1);

Cols = 4;
% plot each state
[n,n_x]=size(GDT(i_opt).X_hist);
tt = [1:n]'-1;
for s = 1:n_x
    subplot(n_x,Cols,(s-1)*Cols+1)
    stairs(tt,GDT(i_opt).X_hist(:,s));
    if s==1, title('X_n'); end
    ax = axis; axis([0 n+1 ax(3:4)]);
end
xlabel(sprintf('n=%d',n-1))

% Plot control actions
% Find absolute control values
if GDT(i_opt).DELTAU
    Useq = cumsum(GDT(i_opt).U_hist); 
else 
    Useq = GDT(i_opt).U_hist; 
end
[n,n_u]=size(Useq);
tt = [1:n]'-1;
for s=1:n_u
    % [2*n_u,Cols], 2nd col, 1,3,5,... row
    p=2+Cols*(s-1);
    subplot(n_u,Cols,p)
    stairs(tt,Useq(:,s));
    if s==1, title('U_n'); end
    ax=axis; axis([0 n+1 ax(3:4)])
    xlabel(sprintf('A_n(%d,%d)=%g',s,s,GDT(i_opt).A_n(s,s)));    
end

% Plot plant outputs
Yref = GDT(i_opt).Yref;
T = size(Yref,1);
[n,n_y]=size(GDT(i_opt).Y_hist);
tt = [1:n]'-1;
for s=1:n_y
    subplot(n_y,Cols,(s-1)*Cols+3)
    tt2 = [1:size(Yref,1)]'-1;
    [x1,y1]=stairs(tt,GDT(i_opt).Y_hist(:,s));
    [x2,y2]=stairs(tt2,Yref(:,s));
    plot(x2,y2,'k:',x1,y1,'b-');
    if s==1, title('Y_n'); end   
    ax=axis; axis([0 T+1 ax(3:4)])
    xlabel(sprintf('B_n(%d,%d)=%g',s,s,GDT(i_opt).B_n(s,s)));
end

% Plot costs
N = length(GDT);
subplot(2,Cols,Cols); 
yh = GDT(i_opt).J_hist;
yh(:,2:3) = cumsum(GDT(i_opt).J_hist(:,2:3));
ii = [1:n]'-1;
plot(ii,yh(:,1),'k-',ii,yh(:,2),'r:',ii,yh(:,3),'b:')
text(n,yh(n,1),'J_n');
text(n,yh(n,2),sprintf('\\SigmaJ_Y'),'color','r');
if GDT(i_opt).DELTAU
    title(sprintf('J_n(\\DeltaU)=%g',GDT(i_opt).J_T));
else
    title(sprintf('J_n(U)=%g',GDT(i_opt).J_T));
end
text(n,yh(n,3),sprintf('\\SigmaJ_U'),'color','b');
ax = axis; axis([0 n+1 ax(3:4)]);

% Plot info on current set of solutions
% - # different solutions
% -survival rate
subplot(2,Cols,2*Cols)
if N>1
    SH=sum(sign(diff(sort([GDT.parent_hist]'))))+1;
    ii = find(SH>1); 
    if length(ii), ip = [max(1,ii(1)-5):n]';
    else, ip=[1:n]'; 
    end
    semilogy([1:n]'-1,100*GDT(1).survived/N,'b-',ip,100*SH(ip)/N,'r-'); 
    text(0,100*SH(ip(1))/N,sprintf('%d',SH(ip(1))),'ver','top')
else
    semilogy([1:n]'-1,100*GDT(1).survived/GDT(1).N,'b-'); 
end
% # different solutions
axis([0 n+1 100/GDT(1).N 110]);
set(gca,'ytick',10.^[0:ceil(log10(GDT(1).N)+eps)])
title(sprintf('^{n+1}/_n %g%%',100*mean(GDT(1).survived/GDT(1).N)))
%title(sprintf('%g%% Survivors',SH(n)/N*100))
xlabel(sprintf('N=%d,   \\beta=%g',GDT(1).N,GDT(i_opt).bet));

set(gcf,'Name',sprintf('Open-loop GDT optimization of %s',GDT(i_opt).plantfunstr));
shg;