function [yn1,xn1] = typicalplant(xn,un,Ts,u0)
% TYPICALPLANT Sample plant described by a discrete-time state-space model
%   [yn1,xn1] = typicalplant(xn,un,Ts,u0)

% Enso Ikonen 4/2006 University of Oulu

% default arguments
if nargin==0
    % proper initial values
    yn1 = zeros(2,1);
    xn1 = zeros(4,1);
    %xn1 = zeros(2,1);
    return;
end
% reasonable additional argument values
if nargin<4, Ts = 1; u0 = zeros(2,1);
elseif nargin<3, Ts = 1;
end

if exist('tf','file')
    % if Control System Toolbox exists, then discretize a TITO LTI system
    % define a TITO system
    sysc = tf({2,[-10 1];0,1},{[10 1],[100 20 1];1,[2 1]});    % continuous plant
    %sysc = tf({2,0;0,1},{[10 1],1;1,[2 1]});    % continuous plant
    sysd = c2d(sysc,Ts);    % sampled system
    [A,B,C,D]=ssdata(sysd);  % sampled state-space system
else
    % no CST-Toolbox
    A(1,1)=0.90484; A(2,2:3)=[1.8097,-0.81873];A(3,2)=1;A(4,4)=0.60653;
    B(1,1)=0.5; B(2,2)=0.5; B(4,2)=0.5;
    C=[0.38065     -0.17161      0.18972]; C(2,4)=0.78694;
    D=zeros(2,2);
end
un = un+u0;             % add control increments to initial control
% state-space model:
xn1=A*xn+B*un;          % state equations
yn1=C*xn1;              % measurement equations